@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2011 Dariusz Suchojad <dsuch at zato.io>
+Copyright (C) 2019, Zato Source s.r.o. https://zato.io
 
 Licensed under LGPLv3, see LICENSE.txt for terms and conditions.
 """
@@ -14,8 +14,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 # LMC stands for the 'log message code'
 # CID stands for the 'correlation ID'
 
-# Needs to be kept in sync with zato.common.util.new_cid
-CID_LENGTH = 40
+CID_LENGTH = 24
 
 NULL_LMC = '0000.0000'
-NULL_CID = 'K' + '0' * (CID_LENGTH - 1)
+NULL_CID = '0' * CID_LENGTH
